import {Component, NgZone, OnInit, ViewChild} from '@angular/core';
import {ElectronService} from './core/services';
import {APP_CONFIG} from '../environments/environment';
import {ModelComponentType} from "./game-model/ModelComponentType";
import {MatDrawerContainer} from "@angular/material/sidenav";
import {ModelComponentTypeUtillities} from "./game-model/ModelComponentTypeUtillities";
import {GameModel} from "./game-model/GameModel";
import {EditorComponent} from "./editor/editor.component";
import {ModelComponent} from "./game-model/ModelComponent";
import {
  ScriptAccountOverviewComponent
} from "./side-overviews/script-account-overview/script-account-overview.component";
import {MatDialog} from "@angular/material/dialog";
import {DeleteConfirmationDialogComponent} from "./delete-confirmation-dialog/delete-confirmation-dialog.component";
import {ScriptAccount} from "./game-model/scriptAccounts/ScriptAccount";

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent implements OnInit{

  openContent : ModelComponentType | undefined = undefined;
  @ViewChild('drawer') drawer: MatDrawerContainer|undefined
  @ViewChild('editor') editor: EditorComponent|undefined
  @ViewChild('scriptAccountOverview') scriptAccountOverview: ScriptAccountOverviewComponent | undefined

  gameModel: GameModel | undefined

  constructor(private electronService: ElectronService,
              private zone: NgZone,
              private dialog: MatDialog
  ) {
    console.log('APP_CONFIG', APP_CONFIG);

    if (electronService.isElectron) {
      console.log(process.env);
      console.log('Run in electron');
      console.log('Electron ipcRenderer', this.electronService.ipcRenderer);
      console.log('NodeJS childProcess', this.electronService.childProcess);

      electronService.ipcRenderer.on('context-menu', (event: any, message: string) => {
        this.zone.run(() => {
          if(message == "edit") {
            if(this.openContent == ModelComponentType.SCRIPTACCOUNT && this.scriptAccountOverview != undefined && this.scriptAccountOverview.selectedScriptAccount != undefined) {
              this.editor!.openGameModelComponent(this.scriptAccountOverview.selectedScriptAccount!);
            }
          } else if(message == "delete") {
            const affectedModelComponent = this.getSelectedModelComponent();
            const dialogRef = this.dialog.open(DeleteConfirmationDialogComponent, {data: affectedModelComponent, minWidth: "400px"});

            dialogRef.afterClosed().subscribe(res => {
              if(res != undefined && res) {
                if(affectedModelComponent instanceof ScriptAccount) {
                  this.gameModel!.removeScriptAccount(affectedModelComponent);
                }
              }
            })
          }
        })
      })
    } else {
      console.log('Run in browser');
    }
  }

  private getSelectedModelComponent(): ModelComponent | undefined {
    if(this.openContent == ModelComponentType.SCRIPTACCOUNT) {
      if(this.scriptAccountOverview != undefined) {
        return this.scriptAccountOverview!.selectedScriptAccount;
      } else {
        console.log("[WARN] [App.component] ScriptAccountOverview is undefined")
      }
    }
    return undefined;
  }

  ngOnInit() {
    this.gameModel = new GameModel("No More");
    this.gameModel.addScriptAccount("Temperature");
    this.gameModel.addScriptAccount("Luftfeuchtigkeit");
  }

  openScriptAccountsOverview() {
    this.openContent = ModelComponentType.SCRIPTACCOUNT
    this.drawer!.open();
  }

  protected readonly ModelComponentType = ModelComponentType;

  closeContentOverview() {
    this.drawer!.close();
    this.openContent = undefined;
  }

  protected readonly ModelComponentTypeUtillities = ModelComponentTypeUtillities;

  openModelComponent(modelComponent: ModelComponent) {
    if(this.editor != undefined) {
      this.editor.openGameModelComponent(modelComponent);
    } else {
      console.log("[WARN] [App.Component] Editor is undefined")
    }

  }
}
