import {Component, EventEmitter, Input, NgZone, Output} from '@angular/core';
import {GameModel} from "../../game-model/GameModel";
import {ScriptAccount} from "../../game-model/scriptAccounts/ScriptAccount";
import {ElectronService} from "../../core/services";

@Component({
  selector: 'app-script-account-overview',
  templateUrl: './script-account-overview.component.html',
  styleUrl: './script-account-overview.component.css'
})
export class ScriptAccountOverviewComponent {
  @Input("gameModel") gameModel: GameModel | undefined
  @Output("onOpenScriptAccount") openScriptAccountEmitter: EventEmitter<ScriptAccount> = new EventEmitter<ScriptAccount>();

  selectedScriptAccount: ScriptAccount | undefined

  constructor(private electronService: ElectronService,
              private zone: NgZone) {
    if(electronService.isElectron) {
      this.electronService.ipcRenderer.on('context-menu', (event: any, message: string) => {
        this.zone.run(() => {
          if(message == "new-scriptaccount") {
            this.onCreateNewScriptAccount()
          }
        })
      })
    }
  }

  onOpenScriptAccount(scriptAccount: ScriptAccount) {
    console.log("onOpenScriptAccount (overview)")
    this.openScriptAccountEmitter.emit(scriptAccount);
  }

  onCreateNewScriptAccount() {
    const scriptAccount = this.gameModel!.addScriptAccount("New ScriptAccount");
    if(scriptAccount != undefined) {
      this.openScriptAccountEmitter.emit(scriptAccount);
    }
  }


  selectScriptAccount(scriptAccount: ScriptAccount) {
    this.selectedScriptAccount = scriptAccount;
  }
}
